"""
    EMIL GdvService

    The EMIL GdvService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.accounting
from eis.accounting.api.messages_api import MessagesApi  # noqa: E501


class TestMessagesApi(unittest.TestCase):
    """MessagesApi unit test stubs"""

    def setUp(self):
        self.api = MessagesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_request_message(self):
        """Test case for get_request_message

        Retrieve the request message  # noqa: E501
        """
        pass

    def test_get_response_message(self):
        """Test case for get_response_message

        Retrieve the response message  # noqa: E501
        """
        pass

    def test_list_all_messages(self):
        """Test case for list_all_messages

        List messages  # noqa: E501
        """
        pass

    def test_list_requests_messages(self):
        """Test case for list_requests_messages

        List requests messages  # noqa: E501
        """
        pass

    def test_list_responses_messages(self):
        """Test case for list_responses_messages

        List responses messages  # noqa: E501
        """
        pass

    def test_update_request_message(self):
        """Test case for update_request_message

        Update the request message  # noqa: E501
        """
        pass

    def test_update_response_message(self):
        """Test case for update_response_message

        Update the request message  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
