"""
    EMIL GdvService

    The EMIL GdvService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.accounting
from eis.accounting.model.address_class import AddressClass
from eis.accounting.model.vba_response_class import VbaResponseClass
globals()['AddressClass'] = AddressClass
globals()['VbaResponseClass'] = VbaResponseClass
from eis.accounting.model.vba_class import VbaClass


class TestVbaClass(unittest.TestCase):
    """VbaClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testVbaClass(self):
        """Test VbaClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = VbaClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
