"""
    EMIL GdvService

    The EMIL GdvService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.accounting
from eis.accounting.model.create_vbuv_response_class import CreateVbuvResponseClass


class TestCreateVbuvResponseClass(unittest.TestCase):
    """CreateVbuvResponseClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateVbuvResponseClass(self):
        """Test CreateVbuvResponseClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateVbuvResponseClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
